ReiL - A Reinforcement Learning Package
=======================================

.. image:: https://img.shields.io/pypi/v/Reil   :alt: PyPI

.. image:: https://img.shields.io/pypi/l/ReiL   :alt: PyPI - License



My codes for a Reinforcement Learning framework!

Installation
------------

.. code-block:: bash

   pip install ReiL
